==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageGCSFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageRegistryConfigStorageGCSFluentImpl<A extends ImageRegistryConfigStorageGCSFluent<A>> extends BaseFluent<A> implements ImageRegistryConfigStorageGCSFluent<A>{
  public ImageRegistryConfigStorageGCSFluentImpl() {
  }
  public ImageRegistryConfigStorageGCSFluentImpl(ImageRegistryConfigStorageGCS instance) {
    this.withBucket(instance.getBucket()); 
    this.withKeyID(instance.getKeyID()); 
    this.withProjectID(instance.getProjectID()); 
    this.withRegion(instance.getRegion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String bucket;
  private String keyID;
  private String projectID;
  private String region;
  private Map<String,Object> additionalProperties;
  public String getBucket() {
    return this.bucket;
  }
  public A withBucket(String bucket) {
    this.bucket=bucket; return (A) this;
  }
  public Boolean hasBucket() {
    return this.bucket != null;
  }
  public String getKeyID() {
    return this.keyID;
  }
  public A withKeyID(String keyID) {
    this.keyID=keyID; return (A) this;
  }
  public Boolean hasKeyID() {
    return this.keyID != null;
  }
  public String getProjectID() {
    return this.projectID;
  }
  public A withProjectID(String projectID) {
    this.projectID=projectID; return (A) this;
  }
  public Boolean hasProjectID() {
    return this.projectID != null;
  }
  public String getRegion() {
    return this.region;
  }
  public A withRegion(String region) {
    this.region=region; return (A) this;
  }
  public Boolean hasRegion() {
    return this.region != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigStorageGCSFluentImpl that = (ImageRegistryConfigStorageGCSFluentImpl) o;
    if (bucket != null ? !bucket.equals(that.bucket) :that.bucket != null) return false;
    if (keyID != null ? !keyID.equals(that.keyID) :that.keyID != null) return false;
    if (projectID != null ? !projectID.equals(that.projectID) :that.projectID != null) return false;
    if (region != null ? !region.equals(that.region) :that.region != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bucket,  keyID,  projectID,  region,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bucket != null) { sb.append("bucket:"); sb.append(bucket + ","); }
    if (keyID != null) { sb.append("keyID:"); sb.append(keyID + ","); }
    if (projectID != null) { sb.append("projectID:"); sb.append(projectID + ","); }
    if (region != null) { sb.append("region:"); sb.append(region + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageGCSFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageRegistryConfigStorageGCSFluentImpl<A extends ImageRegistryConfigStorageGCSFluent<A>> extends BaseFluent<A> implements ImageRegistryConfigStorageGCSFluent<A>{
  public ImageRegistryConfigStorageGCSFluentImpl() {
  }
  public ImageRegistryConfigStorageGCSFluentImpl(ImageRegistryConfigStorageGCS instance) {
    if (instance != null) {
      this.withBucket(instance.getBucket());
      this.withKeyID(instance.getKeyID());
      this.withProjectID(instance.getProjectID());
      this.withRegion(instance.getRegion());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String bucket;
  private String keyID;
  private String projectID;
  private String region;
  private Map<String,Object> additionalProperties;
  public String getBucket() {
    return this.bucket;
  }
  public A withBucket(String bucket) {
    this.bucket=bucket; return (A) this;
  }
  public Boolean hasBucket() {
    return this.bucket != null;
  }
  public String getKeyID() {
    return this.keyID;
  }
  public A withKeyID(String keyID) {
    this.keyID=keyID; return (A) this;
  }
  public Boolean hasKeyID() {
    return this.keyID != null;
  }
  public String getProjectID() {
    return this.projectID;
  }
  public A withProjectID(String projectID) {
    this.projectID=projectID; return (A) this;
  }
  public Boolean hasProjectID() {
    return this.projectID != null;
  }
  public String getRegion() {
    return this.region;
  }
  public A withRegion(String region) {
    this.region=region; return (A) this;
  }
  public Boolean hasRegion() {
    return this.region != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigStorageGCSFluentImpl that = (ImageRegistryConfigStorageGCSFluentImpl) o;
    if (!java.util.Objects.equals(bucket, that.bucket)) return false;

    if (!java.util.Objects.equals(keyID, that.keyID)) return false;

    if (!java.util.Objects.equals(projectID, that.projectID)) return false;

    if (!java.util.Objects.equals(region, that.region)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bucket,  keyID,  projectID,  region,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bucket != null) { sb.append("bucket:"); sb.append(bucket + ","); }
    if (keyID != null) { sb.append("keyID:"); sb.append(keyID + ","); }
    if (projectID != null) { sb.append("projectID:"); sb.append(projectID + ","); }
    if (region != null) { sb.append("region:"); sb.append(region + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
